@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduz %1 a la to llingua nativa usando %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Iconu diseñáu por %1.</translation>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>All Videos</source>
         <translation type="unfinished"/>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Llimpiar</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 reproducciones</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esto ye namái la versión demo de %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Namái pues descargar vídeos de duración menor que %1 minutos pa que puedas probar la función de descarga.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Siguir</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Consigui la versión completa</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 descargáu en %2</translation>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Flotar na parte superior</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Detener tres d&apos;esti videu</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>¿&amp;Préstate %1? ¡Puntúalo!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Anovar</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Esto ye namái la versión de prueba de %1.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esto ye namái la versión demo de %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Déxate probar l&apos;aplicación y ver si te funciona.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Consigui la versión completa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Siguir</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Descargando %1</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation type="unfinished"/>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 reproducciones</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 de %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Guetando...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Amosar %1 más</translation>
@@ -1071,25 +1070,16 @@
         <translation>Bienveníu a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Escribi</translation>
+        <source>to start watching videos.</source>
+        <translation>pa entamar a ver vídeos.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>una pallabra clave</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>una canal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>pa entamar a ver vídeos.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>ver</translation>
+        <source>Enter</source>
+        <translation>Escribi</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Atrás</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Dir a %1</translation>
@@ -1163,13 +1157,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Nun pue obtenese&apos;l fluxu de videu pa %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Tol mundu</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Nun pue obtenese&apos;l fluxu de videu pa %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
