@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Oversæt %1 til din modersmål ved hjælp af %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Ikon designet af %1.</translation>
@@ -96,7 +104,7 @@
     <name>AppWidget</name>
     <message>
         <source>Download</source>
-        <translation type="unfinished"/>
+        <translation>Hent</translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Show opdateret</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Du har ingen abonnementer. Brug stjernetegnet til at abonnere på kanaler.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Alle videoer</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Der er ingen opdateringer i de abonnerede.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Du har ingen abonnementer. Brug stjernetegnet til at abonnere på kanaler.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Fjern</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 visninger</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Dette er kun demoversionen af %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Det kan kun hente videoer kortere end %1 minut, så du kan teste downloadfunktionaliteten.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Forsæt</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Hent den fulde version</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 downloaded på %2</translation>
@@ -633,10 +637,6 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
         <source>&amp;Float on Top</source>
         <translation>&amp;Behold øverst</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Juster vinduesstørrelse</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Stop efter denne video</translation>
@@ -667,10 +667,18 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
     </message>
     <message>
         <source>Restricted Mode</source>
-        <translation type="unfinished"/>
+        <translation>Begrænset-Måde</translation>
     </message>
     <message>
         <source>Hide videos that may contain inappropriate content</source>
+        <translation>Gem videoer der muligvis indeholder stødene indhold.</translation>
+    </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -797,6 +805,10 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
         <source>Update</source>
         <translation>Opdatér</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -812,22 +824,6 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
         <source>The link will be valid only for a limited time.</source>
         <translation>Linket vil kun være gyldigt i en begrænset periode.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Dette er kun demoversionen af %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Det giver dig mulighed for at teste programmet og se om det virker for dig.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Hent den fulde version</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Forsæt</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Downloader %1</translation>
@@ -859,6 +855,10 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
         <source>Subscribe to %1</source>
         <translation>Abonner på %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Abonnerer ikke længere på %1</translation>
@@ -903,11 +903,14 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 visninger</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 af %2 (%3) — %4</translation>
@@ -947,10 +950,6 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Søger...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Vis %1 mere</translation>
@@ -1072,25 +1071,16 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
         <translation>Velkommen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Indtast</translation>
+        <source>to start watching videos.</source>
+        <translation>for at  begynde at se video.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>et nøgleord</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>en kanal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>for at  begynde at se video.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Afspil</translation>
+        <source>Enter</source>
+        <translation>Indtast</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1111,6 +1101,10 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
         <source>&amp;Back</source>
         <translation>&amp;Tilbage</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Frem til %1</translation>
@@ -1161,14 +1155,7 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
     </message>
     <message>
         <source>Downloading %1...</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Kan ikke hente videostrøm for %1</translation>
+        <translation>Henter %1...</translation>
     </message>
 </context>
 <context>
@@ -1366,4 +1353,11 @@ Kopiér &amp;URL&apos;en til videostrømmen</translation>
         <translation>Hele verden</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Kan ikke hente videostrøm for %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
