@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Übersetzen Sie %1 in Ihre Muttersprache mit %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Icons wurden gestaltet von %1.</translation>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Zeige aktualisierte</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Du hast keine Abonnements. Benutze das Stern-Symbol, um einen Kanal zu abonnieren.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Alle Videos</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Zurzeit gibt es nichts Neues bei den Abonnements.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Du hast keine Abonnements. Benutze das Stern-Symbol, um einen Kanal zu abonnieren.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Säubern</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 mal betrachtet</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Dies ist nur die Demoversion von %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Sie kann nur Videos herunterladen, die kürzer als %1 Minuten sind, um die Funktion zum Herunterladen zu testen.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Fortfahren</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Die Vollversion kaufen</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 heruntergeladen nach %2</translation>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>Im Vordergrund &amp;bleiben</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Fenstergröße anpassen</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>Nach diesem Video &amp;anhalten</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation>Verstecke Videos die unpassende Inhalte enthalten können</translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>&amp;Gefällt Ihnen %1? Bewertung abgeben!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Aktualisierung</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Der Link wird nur eine beschränkte Zeit gültig sein.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Dies ist nur die Demoversion von %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Sie erlaubt es Ihnen, die Anwendung zu testen und zu schauen, ob sie bei Ihnen läuft.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Die Vollversion kaufen</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Fortfahren</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>%1 herunterladen</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>Abonnieren von %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Abonnement von %1 wurde aufgehoben.</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 mal betrachtet</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 von %2 (%3) – %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Suche...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Weitere %1 zeigen</translation>
@@ -1071,25 +1070,16 @@
         <translation>Willkommen bei &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Eingeben</translation>
+        <source>to start watching videos.</source>
+        <translation>um die Wiedergabe zu starten.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>ein Suchbegriff</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>ein Kanal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>um die Wiedergabe zu starten.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Anschauen</translation>
+        <source>Enter</source>
+        <translation>Eingeben</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Zurück</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Weiter zu %1</translation>
@@ -1163,13 +1157,6 @@
         <translation>heruntergeladen %1</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Videostream für %1 konnte nicht geöffnet werden</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Weltweit</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Videostream für %1 konnte nicht geöffnet werden</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
