@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduce %1 a tu idioma natal usando %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Iconos diseñados por %1.</translation>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Show actualizado</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>No tiene suscripciones. Haga click en el ícono de la estrella para suscribirse a un canal</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Todos los videos</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>No hay actualizaciones a sus suscripciones en este momento</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>No tiene suscripciones. Haga click en el ícono de la estrella para suscribirse a un canal</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Limpiar</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 visitas</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esta es sólo una versión de demostración de %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Sólo se pueden bajar videos de menos de %1 minutos, para probar la funcionalidad de descarga.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Consigue la versión completa</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 descargado en %2</translation>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Siempre Visible</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>Ajustar el tamaño de la ventana</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Finalizar Después de este Video</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation>Ocultar videos que puedan tener contenido inapropiado</translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>¿Amas %1? ¡Califícalo!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Actualizar</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>El enlace va a ser válido sólo por un tiempo limitado.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esta es sólo la versión de demostración de %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Te permite probar la aplicación y ver si te funciona.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Conseguir la versión completa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Descargando %1</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>Suscribirse a %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Desubscripto de %1</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 visitas</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 of %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Buscando...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Mostrar %1 más</translation>
@@ -1071,25 +1070,16 @@
         <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Escribir</translation>
+        <source>to start watching videos.</source>
+        <translation>para empezar a ver videos.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>una palabra clave</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>un canal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>para empezar a ver videos.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Ver</translation>
+        <source>Enter</source>
+        <translation>Escribir</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Atrás</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Avanzar a %1</translation>
@@ -1163,13 +1157,6 @@
         <translation>Descargando %1...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>No puedo obtener el stream de video de %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Todo el mundo</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>No puedo obtener el stream de video de %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
