@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traducir %1 a tu idioma nativo usando %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Ícono diseñado por %1</translation>
@@ -54,7 +62,7 @@
     </message>
     <message>
         <source>&amp;Code:</source>
-        <translation>&amp;Códico</translation>
+        <translation>&amp;Código</translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Mostrar actualizados</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>No tienes suscripciones. Usa el símbolo de estrella para suscribirte a los canales.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Todos los vídeos</translation>
@@ -169,23 +181,12 @@
     </message>
     <message>
         <source>Unsubscribe</source>
-        <translation>Quitar suscripción</translation>
+        <translation>Cancelar suscripción</translation>
     </message>
     <message>
         <source>There are no updated subscriptions at this time.</source>
         <translation>No hay suscripciones actualizadas</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>No tienes suscripciones. Usa el símbolo de estrella para suscribirte a los canales.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Limpiar</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 vistas</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esta es la versión demostrativa de %1</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Sólo puede descargar videos con duración menor a %1 minutos asi que puedes probar la funcionalidad de descarga</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obtener la versión completa</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>Descargados %1 en %2</translation>
@@ -630,11 +634,7 @@
     </message>
     <message>
         <source>&amp;Float on Top</source>
-        <translation>%Mantener arriba</translation>
-    </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Ajustar tamaño de ventana</translation>
+        <translation>&amp;Mantener arriba</translation>
     </message>
     <message>
         <source>&amp;Stop After This Video</source>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation>Ocultar vídeos que pueden tener contenido inapropiado</translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>&amp;Amas %1? Calíficalo!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Actualizar</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>El vínculo será válido sólo por un tiempo limitado</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esta es la versión demostrativa de %1</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Le permite probar la aplicación y ver si funciona para ti.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obtener la versión completa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Descargando %1</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>Suscribir a %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Desuscribir de %1</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 vistas</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 de %2 (%3) - %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Buscando...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Mostrar %1 más</translation>
@@ -1071,25 +1070,16 @@
         <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Introduzca</translation>
+        <source>to start watching videos.</source>
+        <translation>para ver vídeos</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>una palabra clave</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>un canal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>para ver vídeos</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Ver</translation>
+        <source>Enter</source>
+        <translation>Introduzca</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>Retroceder</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Avanzar a %1 </translation>
@@ -1163,13 +1157,6 @@
         <translation>Descargando %1...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>No se puede obtener el vídeo para %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Mundial</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>No se puede obtener el vídeo para %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
