@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduisez %1 dans votre langue native en utilisant %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation>Logiciel open-source</translation>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Icône dessinée par %1.</translation>
@@ -107,7 +115,7 @@
     </message>
     <message numerus="yes">
         <source>You have %n new video(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Vous avez %n nouvelle vidéo</numerusform><numerusform>Vous avez %n nouvelles vidéos</numerusform></translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Afficher les mises à jours</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Vous n&apos;avez pas d&apos;abonnements. Utilisez le symbole en forme d&apos;étoile pour vous abonner à des chaines,</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Toutes les vidéos</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Il n&apos;y a pas d&apos;abonnements mis à jour en ce moment.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Vous n&apos;avez pas d&apos;abonnements. Utilisez le symbole en forme d&apos;étoile pour vous abonner à des chaines,</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Nettoyer </translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -195,19 +196,38 @@
     </message>
     <message numerus="yes">
         <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Il y a une heure</numerusform><numerusform>Il y a %n heures</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n weeks(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Il y a %n jour</numerusform><numerusform>Il y a %n jours</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n month(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Il y a %n mois</numerusform><numerusform>Il y a %n mois</numerusform></translation>
+    </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation>K</translation>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation>M</translation>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation>B</translation>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 vues</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s) ago</source>
+        <translation><numerusform>Il y a %n semaine</numerusform><numerusform>Il y a %n semaines</numerusform></translation>
     </message>
 </context>
 <context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Il s&apos;agit seulement de la version de démonstration de %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Vous ne pouvez télécharger que des vidéos plus courtes que %1 minutes de sorte que vous puissiez tester la fonctionnalité de téléchargement.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuer</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obtenir la version complète</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 téléchargé sur %2</translation>
@@ -277,7 +281,7 @@
     </message>
     <message numerus="yes">
         <source>%n Download(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n téléchargement</numerusform><numerusform>%n téléchargements</numerusform></translation>
     </message>
 </context>
 <context>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Laisser au dessus</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Ajuster la taille de la fenètre</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Arrêter après cette vidéo</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation>Masquer les vidéos qui peuvent contenir un contenu inapproprié</translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation>Bascule la barre de &amp;Menu</translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation>Menu</translation>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>&amp;Aimer %1? Notez-le !</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Mettre à jour</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation>Vous pouvez continuer d&apos;accéder à la barre de menu en appuyant sur la touche ALT</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Le lien ne sera valide que pour un temps limité.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>C&apos;est juste la version démo de %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Cela vous permet de tester l&apos;application et voir si cela fonctionne pour vous.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obtenir la version complète</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuer</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>%1 Téléchargement</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>S&apos;abonner à %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Se désabonner de %1</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 vues</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 de %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Recherche en cours…</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Afficher %1 de plus</translation>
@@ -1071,25 +1070,16 @@
         <translation>Bienvenue sur  &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Entrer</translation>
+        <source>to start watching videos.</source>
+        <translation>pour commencer à regarder des vidéos.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>un mot-clé</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>une chaîne</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>pour commencer à regarder des vidéos.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Regarder</translation>
+        <source>Enter</source>
+        <translation>Entrer</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Retour</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Continuer à %1</translation>
@@ -1163,13 +1157,6 @@
         <translation>Téléchargement de %1...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Impossible d&apos;obtenir le flux vidéo de %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Monde entier</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Impossible d&apos;obtenir le flux vidéo de %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
