@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traducir %1 ao seu idioma empregando %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation>Coa tecnoloxía de %1</translation>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation>Software de fontes abertas</translation>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Icona deseñada por %1.</translation>
@@ -96,7 +104,7 @@
     <name>AppWidget</name>
     <message>
         <source>Download</source>
-        <translation type="unfinished"/>
+        <translation>Descarga</translation>
     </message>
 </context>
 <context>
@@ -107,7 +115,7 @@
     </message>
     <message numerus="yes">
         <source>You have %n new video(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Dispón dun novo vídeo</numerusform><numerusform>Dispón de  %n novos vídeos</numerusform></translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Amosar a actualización</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Non ten subscricións. Utilice o símbolo da estrela para subscribirse ás canles.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Todos os vídeos</translation>
@@ -175,39 +187,47 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Neste momento non ten subscricións de actualización.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Non ten subscricións. Utilice o símbolo da estrela para subscribirse ás canles.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Limpar</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
     <message>
         <source>Just now</source>
-        <translation type="unfinished"/>
+        <translation>Agora mesmo</translation>
     </message>
     <message numerus="yes">
         <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Hai %n hora</numerusform><numerusform>Hai %n horas</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n weeks(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Hai %n dia</numerusform><numerusform>Hai %n dias</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n month(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Hai %n mes</numerusform><numerusform>Hai %n meses</numerusform></translation>
+    </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation>K</translation>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation>M</translation>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation>B</translation>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 vistas</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s) ago</source>
+        <translation><numerusform>Hai %n semana</numerusform><numerusform>Hai %n semanas</numerusform></translation>
     </message>
 </context>
 <context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Isto é só a versión demo de %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Só se poden descargar vídeos curtos de menos de %1 minutos para que poida probar a utilidade de descargas.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obter a versión completa</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 descargado en %2</translation>
@@ -277,7 +281,7 @@
     </message>
     <message numerus="yes">
         <source>%n Download(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n descarga</numerusform><numerusform>%n descargas</numerusform></translation>
     </message>
 </context>
 <context>
@@ -314,19 +318,19 @@
     <name>Extra</name>
     <message>
         <source>The executable file has been tempered with, maybe by a virus.</source>
-        <translation type="unfinished"/>
+        <translation>O ficheiro executable foi manipulado, quizais por un virus.</translation>
     </message>
     <message>
         <source>%1 will not run. Try installing again.</source>
-        <translation type="unfinished"/>
+        <translation>%1 non se executará. Probe a instalalo de novo.</translation>
     </message>
     <message>
         <source>Quit</source>
-        <translation type="unfinished"/>
+        <translation>Saír</translation>
     </message>
     <message>
         <source>Reinstall</source>
-        <translation type="unfinished"/>
+        <translation>Volver instalar</translation>
     </message>
 </context>
 <context>
@@ -594,7 +598,7 @@
     </message>
     <message>
         <source>Show details about video downloads</source>
-        <translation>Mostrar os detalles sobre as descargas de vídeo</translation>
+        <translation>Amosar os detalles sobre as descargas de vídeo</translation>
     </message>
     <message>
         <source>&amp;Download</source>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Flotante e arriba</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Deter despois deste vídeo</translation>
@@ -666,11 +666,19 @@
     </message>
     <message>
         <source>Restricted Mode</source>
-        <translation type="unfinished"/>
+        <translation>Modo restrinxido</translation>
     </message>
     <message>
         <source>Hide videos that may contain inappropriate content</source>
-        <translation type="unfinished"/>
+        <translation>Agochar os vídeos que poidan conter contido inadecuado</translation>
+    </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation>Alternar a barra do &amp;menú</translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation>Menú</translation>
     </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
@@ -750,7 +758,7 @@
     </message>
     <message>
         <source>&amp;Loading...</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Cargando...</translation>
     </message>
     <message>
         <source>Leave &amp;Full Screen</source>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Actualizar</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation>Aínda pode acceder á barra de menús premendo a tecla ALT</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>A ligazón ten validez só por un tempo limitado.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Isto é só a versión demo de %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Permítelle probar o aplicativo e comprobar se vai ao seu xeito.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obter a versión completa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Descargando %1</translation>
@@ -839,7 +835,7 @@
     <message>
         <source>part</source>
         <comment>This is for video parts, as in 'Cool video - part 1'</comment>
-        <translation>peza</translation>
+        <translation>parte</translation>
     </message>
     <message>
         <source>episode</source>
@@ -848,7 +844,7 @@
     </message>
     <message>
         <source>Sent from %1</source>
-        <translation>Enviado desde %1</translation>
+        <translation>Enviado dende %1</translation>
     </message>
     <message>
         <source>Unsubscribe from %1</source>
@@ -858,13 +854,17 @@
         <source>Subscribe to %1</source>
         <translation>Subscribirse a %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation>Cambiado a %1</translation>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
-        <translation type="unfinished"/>
+        <translation>Non está subscrito a %1</translation>
     </message>
     <message>
         <source>Subscribed to %1</source>
-        <translation type="unfinished"/>
+        <translation>Subscrito a %1</translation>
     </message>
 </context>
 <context>
@@ -879,15 +879,15 @@
     </message>
     <message>
         <source>Would you like to download it now?</source>
-        <translation>Queres descargala agora?</translation>
+        <translation>Quere descargala agora?</translation>
     </message>
     <message>
         <source>Skip This Version</source>
-        <translation>Saltar esta versión</translation>
+        <translation>Omitir esta versión</translation>
     </message>
     <message>
         <source>Remind Me Later</source>
-        <translation>Acórdamo máis adiante</translation>
+        <translation>Lembremo máis adiante</translation>
     </message>
     <message>
         <source>Install Update</source>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 vistas</translation>
+        <source>Pick a video</source>
+        <translation>Deleccione un vídeo</translation>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 de %2 (%3) — %4</translation>
@@ -933,7 +936,7 @@
     </message>
     <message>
         <source>Show in %1</source>
-        <translation>Mostrar en %1</translation>
+        <translation>Amosar en %1</translation>
     </message>
     <message>
         <source>Open parent folder</source>
@@ -946,13 +949,9 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Buscando...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
-        <translation>Mostrar %1 máis</translation>
+        <translation>Amosar %1 máis</translation>
     </message>
     <message>
         <source>No videos</source>
@@ -1071,25 +1070,16 @@
         <translation>Benvido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Introduza</translation>
+        <source>to start watching videos.</source>
+        <translation>para comezar a ver vídeos.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>unha palabra clave</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>unha canle</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>para comezar a ver vídeos.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Ver</translation>
+        <source>Enter</source>
+        <translation>Introduza</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Atrás</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation>A&amp;diante</translation>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Ir a %1</translation>
@@ -1160,14 +1154,7 @@
     </message>
     <message>
         <source>Downloading %1...</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Non é posíbel obter o fluxo de vídeo de %1</translation>
+        <translation>Descargando %1...</translation>
     </message>
 </context>
 <context>
@@ -1365,4 +1352,11 @@
         <translation>Todo o mundo</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Non é posíbel obter o fluxo de vídeo de %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
