@@ -19,12 +19,20 @@
     </message>
     <message>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
-        <translation>%2의 계속된 개발을 위해  &lt;a href=&apos;%1&apos;&gt;기부&lt;/a&gt;룰 해주요...</translation>
+        <translation>%2의 계속된 개발을 위해  &lt;a href=&apos;%1&apos;&gt;기부&lt;/a&gt;룰 해주세요.</translation>
     </message>
     <message>
         <source>Translate %1 to your native language using %2</source>
         <translation>%2을(를) 사용해서 %1를 사용자의 언어로 번역 하세요.</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>아이콘 디자인: %1</translation>
@@ -65,7 +73,7 @@
     </message>
     <message>
         <source>This demo has expired.</source>
-        <translation>데모 만료!</translation>
+        <translation>데모버전이 만료되었습니다!</translation>
     </message>
     <message>
         <source>The full version allows you to watch videos without interruptions.</source>
@@ -77,7 +85,7 @@
     </message>
     <message>
         <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>구입하면, 제가 %1를 만드는데 드는 노력을 지원 합니다.</translation>
+        <translation>구입하면, 개발자가 %1를 만드는데 드는 소중한 노력을 지원 합니다.</translation>
     </message>
     <message>
         <source>Use Demo</source>
@@ -96,7 +104,7 @@
     <name>AppWidget</name>
     <message>
         <source>Download</source>
-        <translation type="unfinished"/>
+        <translation>다운로드</translation>
     </message>
 </context>
 <context>
@@ -118,7 +126,7 @@
     </message>
     <message>
         <source>Unwatched Videos</source>
-        <translation>안 본 비디오</translation>
+        <translation>시청하지 않은 비디오</translation>
     </message>
 </context>
 <context>
@@ -149,23 +157,27 @@
     </message>
     <message>
         <source>Mark all as watched</source>
-        <translation>모두 본 걸로 표시</translation>
+        <translation>모두 시청함으로 표시</translation>
     </message>
     <message>
         <source>Show Updated</source>
         <translation>업데이트 표시</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>구독 항목이 없습니다. 채널을 구독 하려면 별 아이콘을 사용 하세요.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>모든 비디오</translation>
     </message>
     <message>
         <source>Unwatched Videos</source>
-        <translation>안 본 비디오</translation>
+        <translation>시청하지 않은 비디오</translation>
     </message>
     <message>
         <source>Mark as Watched</source>
-        <translation>본 비디오로 마크</translation>
+        <translation>모두 시청함으로 표시</translation>
     </message>
     <message>
         <source>Unsubscribe</source>
@@ -175,23 +187,12 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>현재 업데이트된 구독이 없습니다.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>구독 항목이 없습니다. 채널을 구독 하려면 별 아이콘을 사용 하세요.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>지우기</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
     <message>
         <source>Just now</source>
-        <translation type="unfinished"/>
+        <translation>지금</translation>
     </message>
     <message numerus="yes">
         <source>%n hour(s) ago</source>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 조회수</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>%1의 데모 버전 입니다.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>사용자가 다운로드 기능을 테스트 할수 있도록 %1보다 짧은 비디오만 다운로드 됩니다.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>계속</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>풀 버전 구입</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 downloaded in %2</translation>
@@ -314,19 +318,19 @@
     <name>Extra</name>
     <message>
         <source>The executable file has been tempered with, maybe by a virus.</source>
-        <translation type="unfinished"/>
+        <translation>실행 파일이 바이러스 또는 다른 외부 원인에 의해 손상되었습니다.</translation>
     </message>
     <message>
         <source>%1 will not run. Try installing again.</source>
-        <translation type="unfinished"/>
+        <translation>%1을 실행할 수 없습니다. 다시 설치하시기 바랍니다.</translation>
     </message>
     <message>
         <source>Quit</source>
-        <translation type="unfinished"/>
+        <translation>종료</translation>
     </message>
     <message>
         <source>Reinstall</source>
-        <translation type="unfinished"/>
+        <translation>재설치</translation>
     </message>
 </context>
 <context>
@@ -369,15 +373,15 @@
     </message>
     <message>
         <source>Mute</source>
-        <translation>무음</translation>
+        <translation>음소거</translation>
     </message>
     <message>
         <source>Seek forward</source>
-        <translation>앞으로찾기</translation>
+        <translation>되감기</translation>
     </message>
     <message>
         <source>Seek backward</source>
-        <translation>뒤로찾기</translation>
+        <translation>빨리감기</translation>
     </message>
 </context>
 <context>
@@ -422,11 +426,11 @@
     <name>MainWindow</name>
     <message>
         <source>&amp;Window</source>
-        <translation type="unfinished"/>
+        <translation>창 (&amp;W)</translation>
     </message>
     <message>
         <source>&amp;Minimize</source>
-        <translation type="unfinished"/>
+        <translation>최소화 (&amp;M)</translation>
     </message>
     <message>
         <source>&amp;Stop</source>
@@ -434,7 +438,7 @@
     </message>
     <message>
         <source>Stop playback and go back to the search view</source>
-        <translation>재생을 멈추고 검색 보기로 이동</translation>
+        <translation>재생을 멈추고 검색 창로 이동</translation>
     </message>
     <message>
         <source>P&amp;revious</source>
@@ -442,7 +446,7 @@
     </message>
     <message>
         <source>Go back to the previous track</source>
-        <translation>이전트랙으로 이동</translation>
+        <translation>이전 트랙으로 이동</translation>
     </message>
     <message>
         <source>S&amp;kip</source>
@@ -526,7 +530,7 @@
     </message>
     <message>
         <source>Move &amp;Down</source>
-        <translation>아래로이동(&amp;D)</translation>
+        <translation>아래로 이동(&amp;D)</translation>
     </message>
     <message>
         <source>Move down the selected videos in the playlist</source>
@@ -546,7 +550,7 @@
     </message>
     <message>
         <source>Bye</source>
-        <translation>안녕...</translation>
+        <translation>안녕히 가세요.</translation>
     </message>
     <message>
         <source>&amp;Website</source>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>위에 떠있기(&amp;F)</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>이 비디오 재생 후 정지(&amp;S)</translation>
@@ -666,10 +666,18 @@
     </message>
     <message>
         <source>Restricted Mode</source>
-        <translation type="unfinished"/>
+        <translation>제한된 보기</translation>
     </message>
     <message>
         <source>Hide videos that may contain inappropriate content</source>
+        <translation>부적절한 내용을 포함한 동영상 숨기기</translation>
+    </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -750,7 +758,7 @@
     </message>
     <message>
         <source>&amp;Loading...</source>
-        <translation type="unfinished"/>
+        <translation>로딩중 (&amp;L)</translation>
     </message>
     <message>
         <source>Leave &amp;Full Screen</source>
@@ -766,11 +774,11 @@
     </message>
     <message>
         <source>Volume is muted</source>
-        <translation>볼륨 소거됨</translation>
+        <translation>볼륨 음소거됨</translation>
     </message>
     <message>
         <source>Volume is unmuted</source>
-        <translation>볼륨 소거 해제됨</translation>
+        <translation>볼륨 응소거 해제됨</translation>
     </message>
     <message>
         <source>Maximum video definition set to %1</source>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>업데이트</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>해당 링크는 제한된 시간 동안만 유효 합니다.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>%1의 데모 버전 입니다.%1의 데모 버전 입니다.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>이 버전으로 프로그램이 사용자 필요에 맞는지 테스트 할수 있습니다.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>풀 버전 구입</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>계속</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>%1 다운로드</translation>
@@ -834,7 +830,7 @@
     <message>
         <source>of</source>
         <comment>Used in video parts, as in '2 of 3'</comment>
-        <translation>/</translation>
+        <translation>of</translation>
     </message>
     <message>
         <source>part</source>
@@ -859,12 +855,16 @@
         <translation>%1 구독</translation>
     </message>
     <message>
-        <source>Unsubscribed from %1</source>
+        <source>Switched to %1</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Unsubscribed from %1</source>
+        <translation>%1 구독 해지됨</translation>
+    </message>
     <message>
         <source>Subscribed to %1</source>
-        <translation type="unfinished"/>
+        <translation>%1 구독됨</translation>
     </message>
 </context>
 <context>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 views</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 of %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>검색중...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>%1 추가 보기</translation>
@@ -1071,25 +1070,16 @@
         <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;에 오신걸 환영 합니다!</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>언터</translation>
+        <source>to start watching videos.</source>
+        <translation>비디오 보기 시작</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>키워드</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>채널</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>비디오 보기 시작</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>감상</translation>
+        <source>Enter</source>
+        <translation>언터</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>뒤로(&amp;B)</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>%1(으)로 이동</translation>
@@ -1160,14 +1154,7 @@
     </message>
     <message>
         <source>Downloading %1...</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>%1의 비디오 가져올수 없음</translation>
+        <translation>%1 다운로드중</translation>
     </message>
 </context>
 <context>
@@ -1362,7 +1349,14 @@
     </message>
     <message>
         <source>Worldwide</source>
-        <translation>전세계적</translation>
+        <translation>전세계</translation>
+    </message>
+</context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>%1의 비디오 가져올수 없음</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
