@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Terjemah %1 kepada bahasa ibunda anda menggunakan %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation>Diperkasakan oleh %1</translation>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation>Perisian sumber-terbuka</translation>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Ikon direka oleh %1.</translation>
@@ -107,7 +115,7 @@
     </message>
     <message numerus="yes">
         <source>You have %n new video(s)</source>
-        <translation type="unfinished"><numerusform></numerusform></translation>
+        <translation><numerusform>Anda mempunyai %n video baharu</numerusform></translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Papar Dikemaskini</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Anda tidak mempunyai langganan. Gunakan simbol bintang untuk melanggan saluran.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Semua Video</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Tiada langganan dikemaskini buat masa ini.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Anda tidak mempunyai langganan. Gunakan simbol bintang untuk melanggan saluran.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Kosongkan</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -195,19 +196,38 @@
     </message>
     <message numerus="yes">
         <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform></translation>
+        <translation><numerusform>%n jam yang lalu</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n weeks(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform></translation>
+        <translation><numerusform>%n hari yang lalu</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n month(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform></translation>
+        <translation><numerusform>%n bulan yang lalu</numerusform></translation>
+    </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation>K</translation>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation>M</translation>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation>B</translation>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>ditonton %1 kali</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s) ago</source>
+        <translation><numerusform>%n minggu yang lalu</numerusform></translation>
     </message>
 </context>
 <context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Ini hanyalah versi demo %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Ia hanya boleh muat turun video kurang daripada %1 minit supaya anda boleh menguji kefungsian muat turunnya.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Teruskan</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Dapatkan versi penuh</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 dimuat turun dalam %2</translation>
@@ -277,7 +281,7 @@
     </message>
     <message numerus="yes">
         <source>%n Download(s)</source>
-        <translation type="unfinished"><numerusform></numerusform></translation>
+        <translation><numerusform>%n Muat Turun</numerusform></translation>
     </message>
 </context>
 <context>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>Te&amp;rapung Diatas</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Laras Saiz Tetingkap</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Henti Selepas Video Ini</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation>Sembunyi video yang mengandungi kandungan tidak senonoh</translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation>Togol Palang &amp;Menu</translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation>Menu</translation>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>&amp;Suka %1? Beri penarafan!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Kemaskini</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation>Anda masih boleh mencapai palang menu dengan menekan kekunci ALT</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Pautan hanya sah untuk masa yang terhad.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Ini hanyalah versi demo %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Ia membolehkan anda uji aplikasi dan lihat jika ia berfungsi untuk anda.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Dapatkan versi penuh</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Teruskan</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Memuat turun %1</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>Langgan ke %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation>Beralih ke %1</translation>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Nyahlanggan daripada %1</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>ditonton %1 kali</translation>
+        <source>Pick a video</source>
+        <translation>Pilih satu video</translation>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 daripada %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Menggelintar...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Papar %1 Lagi</translation>
@@ -1071,25 +1070,16 @@
         <translation>Selamat datang ke &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Masukkan</translation>
+        <source>to start watching videos.</source>
+        <translation>untuk menonton video.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>kata kunci</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>saluran</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>untuk menonton video.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Tonton</translation>
+        <source>Enter</source>
+        <translation>Masukkan</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Undur</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation>&amp;Maju</translation>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Maju ke %1</translation>
@@ -1163,13 +1157,6 @@
         <translation>Memuat turun %1...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Tidak dapat strim video untuk %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Seluruh Dunia</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Tidak dapat strim video untuk %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
