@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Vertaal %1 naar uw moedertaal met behulp van %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Pictogram ontworpen door %1.</translation>
@@ -96,7 +104,7 @@
     <name>AppWidget</name>
     <message>
         <source>Download</source>
-        <translation type="unfinished"/>
+        <translation>Downloaden</translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Toon bijgewerkte</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>U heeft geen abonnementen. Gebruik het ster-symbool om te abonneren op kanalen.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Alle video&apos;s</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Er zijn op dit moment geen bijgewerkte abonnementen.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>U heeft geen abonnementen. Gebruik het ster-symbool om te abonneren op kanalen.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Wis</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 bekeken</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Dit is slechts de demoversie van %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Het kan alleen maar videos downloaden korter dan %1 minuten zodat u de downloadfunctionaliteit kunt testen.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Ga door</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Verkrijg de volledige versie</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 gedownload in %2</translation>
@@ -314,11 +318,11 @@
     <name>Extra</name>
     <message>
         <source>The executable file has been tempered with, maybe by a virus.</source>
-        <translation type="unfinished"/>
+        <translation>Het uitvoerbare bestand is aangepast, misschien door een virus.</translation>
     </message>
     <message>
         <source>%1 will not run. Try installing again.</source>
-        <translation type="unfinished"/>
+        <translation>%1 kan niet starten. Probeer opnieuw te installeren.</translation>
     </message>
     <message>
         <source>Quit</source>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Zweef erboven</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Stop na deze video</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation>&amp;Menubalk weergeven/verbergen</translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation>Menu</translation>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>Vindt u %1 te &amp;gek? Waardeer het!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Werk bij</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation>U kunt de menubalk nog steeds benaderen door op ALT te drukken</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>De link zal maar een beperkte tijd geldig zijn.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Dit is slechts de demoversie van %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Het biedt de mogelijkheid de applicatie te testen en te beoordelen.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Verkrijg de volledige versie</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Ga door</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Bezig met downloaden van %1</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>Abonneer op %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation type="unfinished"/>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 bekeken</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 van %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Bezig met zoeken...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Toon %1 meer</translation>
@@ -1071,25 +1070,16 @@
         <translation>Welkom bij &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Typ</translation>
+        <source>to start watching videos.</source>
+        <translation>om te beginnen met het bekijken van video&apos;s.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>een zoekwoord</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>een kanaal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>om te beginnen met het bekijken van video&apos;s.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Bekijk</translation>
+        <source>Enter</source>
+        <translation>Typ</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Terug</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Spoel vooruit naar %1</translation>
@@ -1160,14 +1154,7 @@
     </message>
     <message>
         <source>Downloading %1...</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Kan de videostream niet verkrijgen voor %1</translation>
+        <translation>Downloaden van %1...</translation>
     </message>
 </context>
 <context>
@@ -1365,4 +1352,11 @@
         <translation>Wereldwijd</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Kan de videostream niet verkrijgen voor %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
