@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduza %1 para seu idioma nativo usando %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation>Produzido por %1</translation>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation>Software open-source</translation>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Ícone desenhado por %1.</translation>
@@ -107,7 +115,7 @@
     </message>
     <message numerus="yes">
         <source>You have %n new video(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Você tem %n vídeo(s) novo(s)</numerusform><numerusform>Você tem %n vídeo(s) novo(s)</numerusform></translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Mostrar Atualização</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Você não tem assinaturas. Use o símbolo da estrela para assinar canais.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Todos Os Vídeos</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Não há assinaturas atualizadas neste momento.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Você não tem assinaturas. Use o símbolo da estrela para assinar canais.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Limpar</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -195,19 +196,38 @@
     </message>
     <message numerus="yes">
         <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n hora(s) atrás</numerusform><numerusform>%n hora(s) atrás</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n weeks(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n dia(s) atrás</numerusform><numerusform>%n dia(s) atrás</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n month(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n mes(es) atrás</numerusform><numerusform>%n mes(es) atrás</numerusform></translation>
+    </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation>K</translation>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation>M</translation>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation>B</translation>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 visualizações</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s) ago</source>
+        <translation><numerusform>%n semana(s) atrás</numerusform><numerusform>%n semana(s) atrás</numerusform></translation>
     </message>
 </context>
 <context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esta é apenas a versão demonstração de %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Só pode fazer download de vídeos menores que %1 minutos para que você possa testar a funcionalidade de download.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obter a versão completa</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 baixados em %2</translation>
@@ -277,7 +281,7 @@
     </message>
     <message numerus="yes">
         <source>%n Download(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n Downloads</numerusform><numerusform>%n Download(s)</numerusform></translation>
     </message>
 </context>
 <context>
@@ -326,7 +330,7 @@
     </message>
     <message>
         <source>Reinstall</source>
-        <translation>Reinstale</translation>
+        <translation>Reinstalar</translation>
     </message>
 </context>
 <context>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Sempre Acima</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Ajuste o tamanho da janela</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>&amp;Parar Após Este Vídeo</translation>
@@ -670,7 +670,15 @@
     </message>
     <message>
         <source>Hide videos that may contain inappropriate content</source>
-        <translation>Ocultar vídeos com conteúdo inapropriado</translation>
+        <translation>Ocultar vídeos que podem conter conteúdo inapropriado</translation>
+    </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation>Mostrar Barra De &amp;Menu</translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation>Menu</translation>
     </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Atualizar</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation>Você ainda pode acessar a barra de menu pressionando a tecla ALT</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>O link só será válido por um tempo limitado.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Esta é apenas a versão demonstração de %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Ele permite que você teste o aplicativo e veja se ele funciona para você.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obter a versão completa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Baixando %1</translation>
@@ -858,9 +854,13 @@
         <source>Subscribe to %1</source>
         <translation>Assinar %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation>Mudar para %1</translation>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
-        <translation>Desinscrito de %1</translation>
+        <translation>Não subscrito de %1</translation>
     </message>
     <message>
         <source>Subscribed to %1</source>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 visualizações</translation>
+        <source>Pick a video</source>
+        <translation>Escolher um vídeo</translation>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 de %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Pesquisando...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Mostrar Mais %1</translation>
@@ -1071,25 +1070,16 @@
         <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Digite</translation>
+        <source>to start watching videos.</source>
+        <translation>para começar a assistir vídeos.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>uma palavra-chave</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>um canal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>para começar a assistir vídeos.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Assistir</translation>
+        <source>Enter</source>
+        <translation>Digite</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Voltar</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation>&amp;Avançar</translation>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Avançar para %1</translation>
@@ -1163,13 +1157,6 @@
         <translation>Baixando %1...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Não foi possível obter stream de vídeo de %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Mundial</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Não foi possível obter stream de vídeo de %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
