@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Перевести %1 на ваш родной язык с помощью %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Автор значка %1.</translation>
@@ -156,6 +164,10 @@
         <source>Show Updated</source>
         <translation>Показать обновленные</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>У вас нет подписок. Используйте символ звездочки чтобы подписаться на каналы.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Все видео</translation>
@@ -176,17 +188,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>В настоящее время нет обновлений подписок.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>У вас нет подписок. Используйте символ звездочки чтобы подписаться на каналы.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Очистить</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -203,11 +204,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 просмотров</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -252,22 +272,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Это всего лишь демо версия %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Можно загружать только видео не длиннее %1 минут, для проверки функциональности загрузчика. </translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Продолжить</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Получить полную версию</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 загружен в %2</translation>
@@ -633,10 +637,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Поверх всех окон</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Подстраивать размер окна</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>Ост&amp;ановить после этого видео</translation>
@@ -673,6 +673,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation>Скрыть видео, содержащие недопустимый контент </translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>&amp;Нравится %1? Оцени!</translation>
@@ -797,6 +805,10 @@
         <source>Update</source>
         <translation>Обновление</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -812,22 +824,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Адрес будет существовать ограниченное время.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Данная программа является демо-версией %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Она позволяет вам оценить приложение.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Купить полную версию</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Продолжить</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Загружаю %1</translation>
@@ -859,6 +855,10 @@
         <source>Subscribe to %1</source>
         <translation>Подписаться на %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Отписаны от %1</translation>
@@ -903,11 +903,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 просмотров</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 из %2 (%3) — %4</translation>
@@ -947,10 +950,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Идет поиск...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Показать ещё %1</translation>
@@ -1072,25 +1071,16 @@
         <translation>Добро пожаловать в &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Введите</translation>
+        <source>to start watching videos.</source>
+        <translation>чтобы начать просмотр.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>запрос</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>канал</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>чтобы начать просмотр.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Смотреть</translation>
+        <source>Enter</source>
+        <translation>Введите</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1111,6 +1101,10 @@
         <source>&amp;Back</source>
         <translation>Н&amp;азад</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Вперед к %1</translation>
@@ -1164,13 +1158,6 @@
         <translation>Загрузка %1...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Не удалось получить видео поток для %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1366,4 +1353,11 @@
         <translation>Во всем мире</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Не удалось получить видео поток для %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
