@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Преведите %1 на ваш матерњи језик помоћу %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Иконицу дизајниро %1.</translation>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Прикажи ажурирано</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Немате претплате. Користи звезду да се претплатиш.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Сви видеи</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Нема ажурираних субскрипција тренутно</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Немате претплате. Користи звезду да се претплатиш.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Очисти</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -202,11 +203,30 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
     <message numerus="yes">
-        <source>%n weeks(s) ago</source>
+        <source>%n month(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 прегледа</translation>
+    </message>
     <message numerus="yes">
-        <source>%n month(s) ago</source>
+        <source>%n week(s) ago</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Ово је тек демо верзија  %1.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Може преузети само снимке краће од %1 минута тако да можете испробати употребљивост преузимања.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Настави</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Преузмите пуну верзију</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 преузето у %2</translation>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Флутај на врху</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Прилагоди величину прозора</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>Зау&amp;стави након овог видеа</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>&amp;Обожавате %1? Оцените!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Ажурирај</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Веза је исправна само одређено време.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Ово је тек демо верзија %1.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Омогућава вам да испробате програм и увидите да ли вам одговара.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Преузмите пуну верзију</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Настави</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>преузимам %1</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>Претплати се на %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Ун-претплаћен од %1</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 прегледа</translation>
+        <source>Pick a video</source>
+        <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 од %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Тражим...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Прикажи још %1</translation>
@@ -1071,25 +1070,16 @@
         <translation>Добродошли у &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>унесите</translation>
+        <source>to start watching videos.</source>
+        <translation>да би започели преглед видео снимака.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>кључну реч</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>канал</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>да би започели преглед видео снимака.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Гледај</translation>
+        <source>Enter</source>
+        <translation>унесите</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Назад</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Напред до %1</translation>
@@ -1163,13 +1157,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>не могу да добавим видео ток за %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Широм света</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>не могу да добавим видео ток за %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
