@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>%1&apos;i, %2 kullanarak kendi dilinize çevirin</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation>% 1 tarafından desteklenmektedir</translation>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation>Açık kaynaklı yazılım</translation>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Simge %1 tarafından tasarlandı.</translation>
@@ -107,7 +115,7 @@
     </message>
     <message numerus="yes">
         <source>You have %n new video(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n yeni videonuz var</numerusform><numerusform>%n yeni videonuz var</numerusform></translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Güncellenenleri Göster</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Hiç aboneliğiniz yok. Kanallara abone olmak için yıldız simgesini kullanın.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Tüm Videolar</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Şu anda güncellenen abonelik yok.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Hiç aboneliğiniz yok. Kanallara abone olmak için yıldız simgesini kullanın.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Temizle</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -195,19 +196,38 @@
     </message>
     <message numerus="yes">
         <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>&amp;n saat önce</numerusform><numerusform>&amp;n saat önce</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n weeks(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>&amp;n gün önce</numerusform><numerusform>&amp;n gün önce</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n month(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>&amp;n ay önce</numerusform><numerusform>&amp;n ay önce</numerusform></translation>
+    </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation>K</translation>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation>M</translation>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation>B</translation>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>%1 görüntülenme</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s) ago</source>
+        <translation><numerusform>&amp;n hafta önce</numerusform><numerusform>&amp;n hafta önce</numerusform></translation>
     </message>
 </context>
 <context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Bu sadece %&apos;in demo sürümüdür.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Bu sadece %1 dakikadan kısa videoları indirebilir, indirme özelliğini böylece test edebilirsiniz.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Devam</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Tam sürüme geç</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%2 de %1 indirildi</translation>
@@ -277,7 +281,7 @@
     </message>
     <message numerus="yes">
         <source>%n Download(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>&amp;n İndirme</numerusform><numerusform>&amp;n İndirme</numerusform></translation>
     </message>
 </context>
 <context>
@@ -422,11 +426,11 @@
     <name>MainWindow</name>
     <message>
         <source>&amp;Window</source>
-        <translation>Pencere</translation>
+        <translation>&amp;Pencere</translation>
     </message>
     <message>
         <source>&amp;Minimize</source>
-        <translation>Küçült</translation>
+        <translation>&amp;Küçült</translation>
     </message>
     <message>
         <source>&amp;Stop</source>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>Üstte Sabitle</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Pencere Boyutunu Ayarla</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>Bu Videodan &amp;Sonra Durdur</translation>
@@ -672,6 +672,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation>Uygunsuz içerik içerebilecek videoları gizle</translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation>&amp;Menü Çubuğunu Aç/Kapat</translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation>Menü</translation>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation>%1 &amp;seviyor musunuz? Değerlendirin!</translation>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Güncelle</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation>ALT tuşuna basarak hala menü çubuğuna erişebilirsiniz</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Bağlantı kısıtlı bir süre için geçerli olacak.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Bu sadece %1&apos;in demo sürümüdür.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Bu, uygulamayı test etmenizi ve çalışıp çalışmadığını görmenizi sağlar.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Tam sürüme geç</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Devam</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>İndiriliyor %1</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>%1 Abone Ol</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation>% 1 olarak değiştirildi</translation>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>%1 aboneliğinden çık</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>%1 görüntülenme</translation>
+        <source>Pick a video</source>
+        <translation>Bir video seç</translation>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 of %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Aranıyor...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>%1 Tane Daha Göster</translation>
@@ -1071,25 +1070,16 @@
         <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;a Hoşgeldiniz</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Giriş yapın</translation>
+        <source>to start watching videos.</source>
+        <translation>ve videoları izlemeye başlayın.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>bir anahtar kelime</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>bir kanal</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>ve videoları izlemeye başlayın.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>İzle</translation>
+        <source>Enter</source>
+        <translation>Giriş yapın</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>Geri</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation>&amp;İleri</translation>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>%1 Yönlendir</translation>
@@ -1163,13 +1157,6 @@
         <translation>%1 indiriliyor...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>%1 için video akışı alınamıyor.</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Dünya Çapında</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>%1 için video akışı alınamıyor.</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
