@@ -21,10 +21,8 @@ $END_LICENSE */
 #ifndef DOWNLOADVIEW_H
 #define DOWNLOADVIEW_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
+
 #include "view.h"
 
 class SegmentedControl;
@@ -33,17 +31,15 @@ class DownloadListView;
 class DownloadSettings;
 
 class DownloadView : public View {
-
     Q_OBJECT
 
 public:
     DownloadView(QWidget *parent);
     void appear();
     void disappear();
-    QHash<QString, QVariant> metadata() {
-        QHash<QString, QVariant> metadata;
-        metadata.insert("title", tr("Downloads"));
-        return metadata;
+    const QString &getTitle() {
+        static const QString s = tr("Downloads");
+        return s;
     }
 
 public slots:
@@ -56,7 +52,6 @@ private:
     DownloadModel *listModel;
     QTimer *updateTimer;
     DownloadSettings *downloadSettings;
-
 };
 
 #endif // DOWNLOADVIEW_H
