@@ -19,23 +19,21 @@ along with Minitube.  If not, see <http://www.gnu.org/licenses/>.
 $END_LICENSE */
 
 #include "homeview.h"
-#include "segmentedcontrol.h"
-#include "searchview.h"
-#include "standardfeedsview.h"
+#include "channelaggregator.h"
 #include "channelview.h"
+#include "iconutils.h"
 #include "mainwindow.h"
 #include "mediaview.h"
+#include "searchview.h"
+#include "segmentedcontrol.h"
+#include "standardfeedsview.h"
 #include "ytstandardfeed.h"
-#include "iconutils.h"
-#include "channelaggregator.h"
 #ifdef APP_MAC
 #include "macutils.h"
 #endif
 
-HomeView::HomeView(QWidget *parent) : View(parent),
-    standardFeedsView(0),
-    channelsView(0) {
-
+HomeView::HomeView(QWidget *parent)
+    : View(parent), searchView(nullptr), standardFeedsView(nullptr), channelsView(nullptr) {
     QBoxLayout *layout = new QVBoxLayout(this);
     layout->setMargin(0);
     layout->setSpacing(0);
@@ -45,11 +43,6 @@ HomeView::HomeView(QWidget *parent) : View(parent),
 
     stackedWidget = new QStackedWidget();
     layout->addWidget(stackedWidget);
-
-    searchView = new SearchView(this);
-    connect(searchView, SIGNAL(search(SearchParams*)),
-            MainWindow::instance(), SLOT(showMedia(SearchParams*)));
-    stackedWidget->addWidget(searchView);
 }
 
 void HomeView::setupBar() {
@@ -76,31 +69,29 @@ void HomeView::setupBar() {
     connect(ChannelAggregator::instance(), SIGNAL(unwatchedCountChanged(int)),
             SLOT(unwatchedCountChanged(int)));
 
-    const auto a = bar->actions();
-    for (QAction* action : a) {
+    const auto &a = bar->actions();
+    for (QAction *action : a) {
         addAction(action);
-        IconUtils::setupAction(action);
+        MainWindow::instance()->setupAction(action);
     }
 }
 
 void HomeView::showWidget(QWidget *widget) {
-    QWidget* currentWidget = stackedWidget->currentWidget();
-    if (currentWidget == widget) return;
-    QMetaObject::invokeMethod(currentWidget, "disappear");
-    currentWidget->setEnabled(false);
+    QWidget *currentWidget = stackedWidget->currentWidget();
+    if (currentWidget && currentWidget != widget) {
+        QMetaObject::invokeMethod(currentWidget, "disappear");
+        currentWidget->setEnabled(false);
+    }
     stackedWidget->setCurrentWidget(widget);
     widget->setEnabled(true);
-    QMetaObject::invokeMethod(widget, "appear");
-    QTimer::singleShot(0, widget, SLOT(setFocus()));
-
-#ifdef APP_MAC
-    // Workaround cursor bug on macOS
-    window()->unsetCursor();
-#endif
+    QMetaObject::invokeMethod(widget, "appear", Qt::QueuedConnection);
 }
 
 void HomeView::appear() {
-    QMetaObject::invokeMethod(stackedWidget->currentWidget(), "appear", Qt::QueuedConnection);
+    if (stackedWidget->count() == 0)
+        showSearch();
+    else
+        QMetaObject::invokeMethod(stackedWidget->currentWidget(), "appear", Qt::QueuedConnection);
 }
 
 void HomeView::disappear() {
@@ -108,6 +99,12 @@ void HomeView::disappear() {
 }
 
 void HomeView::showSearch() {
+    if (!searchView) {
+        searchView = new SearchView(this);
+        connect(searchView, SIGNAL(search(SearchParams *)), MainWindow::instance(),
+                SLOT(showMedia(SearchParams *)));
+        stackedWidget->addWidget(searchView);
+    }
     showWidget(searchView);
     bar->setCheckedAction(0);
 }
@@ -115,9 +112,8 @@ void HomeView::showSearch() {
 void HomeView::showStandardFeeds() {
     if (!standardFeedsView) {
         standardFeedsView = new StandardFeedsView();
-        connect(standardFeedsView, SIGNAL(activated(VideoSource*)),
-                MainWindow::instance(),
-                SLOT(showMedia(VideoSource*)));
+        connect(standardFeedsView, SIGNAL(activated(VideoSource *)), MainWindow::instance(),
+                SLOT(showMedia(VideoSource *)));
         stackedWidget->addWidget(standardFeedsView);
     }
     showWidget(standardFeedsView);
@@ -127,9 +123,8 @@ void HomeView::showStandardFeeds() {
 void HomeView::showChannels() {
     if (!channelsView) {
         channelsView = new ChannelView();
-        connect(channelsView, SIGNAL(activated(VideoSource*)),
-                MainWindow::instance(),
-                SLOT(showMedia(VideoSource*)));
+        connect(channelsView, SIGNAL(activated(VideoSource *)), MainWindow::instance(),
+                SLOT(showMedia(VideoSource *)));
         stackedWidget->addWidget(channelsView);
     }
     showWidget(channelsView);
