@@ -18,14 +18,14 @@ along with Minitube.  If not, see <http://www.gnu.org/licenses/>.
 
 $END_LICENSE */
 
-#include <QtWidgets>
 #include <QtNetwork>
+#include <QtWidgets>
 
-#include <qtsingleapplication.h>
 #include "constants.h"
+#include "iconutils.h"
 #include "mainwindow.h"
 #include "searchparams.h"
-#include "iconutils.h"
+#include <qtsingleapplication.h>
 #ifdef APP_EXTRA
 #include "extra.h"
 #endif
@@ -33,19 +33,20 @@ $END_LICENSE */
 #include "mac_startup.h"
 #endif
 
-void showWindow(QtSingleApplication &app, const QString &dataDir) {
+void showWindow(QtSingleApplication &app, const QString &pkgDataDir) {
     MainWindow *mainWin = new MainWindow();
 
 #ifndef APP_MAC
     QIcon appIcon;
-    if (QDir(dataDir).exists()) {
+    if (!pkgDataDir.isEmpty()) {
         appIcon = IconUtils::icon(Constants::UNIX_NAME);
     } else {
         QString dataDir = qApp->applicationDirPath() + "/data";
-        const int iconSizes [] = { 16, 22, 32, 48, 64, 128, 256, 512 };
+        const int iconSizes[] = {16, 22, 32, 48, 64, 128, 256, 512};
         for (int i = 0; i < 8; i++) {
             QString size = QString::number(iconSizes[i]);
-            QString png = dataDir + "/" + size + "x" + size + "/" + Constants::UNIX_NAME + ".png";
+            QString png = dataDir + '/' + size + 'x' + size + '/' + Constants::UNIX_NAME +
+                          QLatin1String(".png");
             appIcon.addFile(png, QSize(iconSizes[i], iconSizes[i]));
         }
     }
@@ -53,8 +54,8 @@ void showWindow(QtSingleApplication &app, const QString &dataDir) {
     mainWin->setWindowIcon(appIcon);
 #endif
 
-    mainWin->connect(&app, SIGNAL(messageReceived(const QString &)),
-                    mainWin, SLOT(messageReceived(const QString &)));
+    mainWin->connect(&app, SIGNAL(messageReceived(const QString &)), mainWin,
+                     SLOT(messageReceived(const QString &)));
     app.setActivationWindow(mainWin, true);
 
     mainWin->show();
@@ -68,18 +69,30 @@ int main(int argc, char **argv) {
     // Seed random number generator
     qsrand(QDateTime::currentDateTime().toTime_t());
 
+#ifdef MEDIA_MPV
+    QSurfaceFormat format = QSurfaceFormat::defaultFormat();
+#ifdef APP_MAC
+    format.setMajorVersion(4);
+    format.setMinorVersion(1);
+#endif
+    format.setProfile(QSurfaceFormat::CoreProfile);
+    QSurfaceFormat::setDefaultFormat(format);
+#endif
+
 #ifdef Q_OS_MAC
     mac::MacMain();
 #endif
 
     QtSingleApplication app(argc, argv);
-    QString message = app.arguments().size() > 1 ? app.arguments().at(1) : QString();
-    if (message == QLatin1String("--help")) {
-        MainWindow::printHelp();
-        return 0;
+    QString message;
+    if (app.arguments().size() > 1) {
+        message = app.arguments().at(1);
+        if (message == QLatin1String("--help")) {
+            MainWindow::printHelp();
+            return 0;
+        }
     }
-    if (app.sendMessage(message))
-        return 0;
+    if (app.sendMessage(message)) return 0;
 
     app.setApplicationName(Constants::NAME);
     app.setOrganizationName(Constants::ORG_NAME);
@@ -96,6 +109,7 @@ int main(int argc, char **argv) {
     cssFile.open(QFile::ReadOnly);
     QString styleSheet = QLatin1String(cssFile.readAll());
     app.setStyleSheet(styleSheet);
+    cssFile.close();
 #endif
 
     // qt translations
@@ -104,28 +118,28 @@ int main(int argc, char **argv) {
                       QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     app.installTranslator(&qtTranslator);
 
-    // app translations
+    QString pkgDataDir;
 #ifdef PKGDATADIR
-    QString dataDir = QLatin1String(PKGDATADIR);
-#else
-    QString dataDir = "";
+    pkgDataDir = QLatin1String(PKGDATADIR);
 #endif
+
+    // app translations
 #ifdef APP_MAC
     QString localeDir = qApp->applicationDirPath() + QLatin1String("/../Resources/locale");
 #else
     QString localeDir = qApp->applicationDirPath() + QLatin1String("/locale");
 #endif
     if (!QDir(localeDir).exists()) {
-        localeDir = dataDir + QLatin1String("/locale");
+        localeDir = pkgDataDir + QLatin1String("/locale");
     }
-    // qDebug() << "Using locale dir" << localeDir << locale;
+    qDebug() << "Using locale dir" << localeDir << QLocale::system();
     QTranslator translator;
     translator.load(QLocale::system(), QString(), QString(), localeDir);
     app.installTranslator(&translator);
 
     QNetworkProxyFactory::setUseSystemConfiguration(true);
 
-    showWindow(app, dataDir);
+    showWindow(app, pkgDataDir);
 
     return app.exec();
 }
