@@ -18,8 +18,8 @@ along with Minitube.  If not, see <http://www.gnu.org/licenses/>.
 
 $END_LICENSE */
 
-#ifndef __SEARCHVIEW_H__
-#define __SEARCHVIEW_H__
+#ifndef SEARCHVIEW_H
+#define SEARCHVIEW_H
 
 #include <QtWidgets>
 
@@ -33,11 +33,10 @@ class Suggestion;
 class ClickableLabel;
 
 class SearchView : public View {
-
     Q_OBJECT
 
 public:
-    SearchView(QWidget *parent = 0);
+    SearchView(QWidget *parent = nullptr);
     void updateRecentKeywords();
     void updateRecentChannels();
 
@@ -49,38 +48,32 @@ public slots:
     void watchKeywords(const QString &query);
 
 signals:
-    void search(SearchParams*);
-
-protected:
-    void paintEvent(QPaintEvent *);
+    void search(SearchParams *);
 
 private slots:
     void watch();
     void textChanged(const QString &text);
     void searchTypeChanged(int index);
     void suggestionAccepted(Suggestion *suggestion);
-    void screenChanged();
-    void onChannelSuggestions(const QVector<Suggestion*> &suggestions);
+    void onChannelSuggestions(const QVector<Suggestion *> &suggestions);
 
 private:
     YTSuggester *youtubeSuggest;
     ChannelSuggest *channelSuggest;
 
-    QComboBox *typeCombo;
     SearchWidget *queryEdit;
     QLabel *recentKeywordsLabel;
     QBoxLayout *recentKeywordsLayout;
     QLabel *recentChannelsLabel;
     QBoxLayout *recentChannelsLayout;
     QLabel *message;
-    QPushButton *watchButton;
 
     QStringList recentKeywords;
     QStringList recentChannels;
 
-    QVector<Suggestion*> lastChannelSuggestions;
+    QVector<Suggestion *> lastChannelSuggestions;
 
     ClickableLabel *logo;
 };
 
-#endif // __SEARCHVIEW_H__
+#endif // SEARCHVIEW_H
