@@ -69,7 +69,8 @@ public:
     const QString &getFormattedDuration() const { return formattedDuration; }
 
     int getViewCount() const { return viewCount; }
-    void setViewCount(int value) { viewCount = value; }
+    void setViewCount(int value);
+    const QString &getFormattedViewCount() const { return formattedViewCount; }
 
     const QDateTime &getPublished() const { return published; }
     void setPublished(const QDateTime &value);
@@ -78,7 +79,9 @@ public:
     int getDefinitionCode() const { return definitionCode; }
 
     void loadStreamUrl();
-    const QUrl &getStreamUrl() { return streamUrl; }
+    const QString &getStreamUrl() { return streamUrl; }
+    bool isLoadingStreamUrl() const { return ytVideo != nullptr; }
+    void abortLoadStreamUrl();
 
     const QString &getId() const { return id; }
     void setId(const QString &value) { id = value; }
@@ -90,12 +93,12 @@ signals:
     void gotThumbnail();
     void gotMediumThumbnail(const QByteArray &bytes);
     void gotLargeThumbnail(const QByteArray &bytes);
-    void gotStreamUrl(const QUrl &streamUrl);
+    void gotStreamUrl(const QString &videoUrl, const QString &audioUrl);
     void errorStreamUrl(const QString &message);
 
 private slots:
     void setThumbnail(const QByteArray &bytes);
-    void streamUrlLoaded(const QUrl &streamUrl);
+    void streamUrlLoaded(const QString &streamUrl, const QString &audioUrl);
 
 private:
     QString title;
@@ -103,7 +106,7 @@ private:
     QString channelTitle;
     QString channelId;
     QString webpage;
-    QUrl streamUrl;
+    QString streamUrl;
     QPixmap thumbnail;
     QString thumbnailUrl;
     QString mediumThumbnailUrl;
@@ -114,6 +117,7 @@ private:
     QDateTime published;
     QString formattedPublished;
     int viewCount;
+    QString formattedViewCount;
     License license;
     QString id;
     int definitionCode;
