@@ -3,11 +3,12 @@
 #include <algorithm>
 #include <ctime>
 
-#include "jsfunctions.h"
+#include "constants.h"
 #include "http.h"
 #include "httputils.h"
-#include "constants.h"
+#include "jsfunctions.h"
 #include "mainwindow.h"
+#include "videodefinition.h"
 
 #ifdef APP_EXTRA
 #include "extra.h"
@@ -55,14 +56,14 @@ void YT3::initApiKeys() {
 #endif
 
 #ifdef APP_EXTRA
-    if (keys.isEmpty())
-        keys << Extra::apiKeys();
+    if (keys.isEmpty()) keys << Extra::apiKeys();
 #endif
 
     if (keys.isEmpty()) {
         qWarning() << "No available API keys";
 #ifdef APP_LINUX
-        QMetaObject::invokeMethod(MainWindow::instance(), "missingKeyWarning", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(MainWindow::instance(), "missingKeyWarning",
+                                  Qt::QueuedConnection);
 #endif
     } else {
         key = keys.takeFirst();
@@ -99,6 +100,18 @@ QUrl YT3::method(const QString &name) {
     return url;
 }
 
+const VideoDefinition &YT3::maxVideoDefinition() {
+    const QString name = QSettings().value("definition", "720p").toString();
+    const VideoDefinition &definition = VideoDefinition::forName(name);
+    return definition;
+}
+
+void YT3::setMaxVideoDefinition(const QString &name) {
+    QSettings settings;
+    settings.setValue("definition", name);
+    emit maxVideoDefinitionChanged(name);
+}
+
 void YT3::testResponse(const HttpReply &reply) {
     int status = reply.statusCode();
     if (status != 200) {
