@@ -2,23 +2,19 @@
 #define YT3LISTPARSER_H
 
 #include <QtCore>
-#include <QtScript>
 
 class Video;
 
 class YT3ListParser : public QObject {
-
 public:
     YT3ListParser(const QByteArray &bytes);
-    const QList<Video*> &getVideos() { return videos; }
-    const QStringList &getSuggestions() { return suggestions; }
+    const QVector<Video *> &getVideos() { return videos; }
     const QString &getNextPageToken() { return nextPageToken; }
 
 private:
-    void parseItem(const QScriptValue &item);
+    void parseItem(const QJsonObject &item);
 
-    QList<Video*> videos;
-    QStringList suggestions;
+    QVector<Video *> videos;
     QString nextPageToken;
 };
 
