@@ -33,7 +33,7 @@ public:
     void suggest(const QString &query);
 
 signals:
-    void ready(const QList<Suggestion*> &suggestions);
+    void ready(const QVector<Suggestion*> &suggestions);
 
 private slots:
     void handleNetworkData(QByteArray response);
